Documentation
¶
Index ¶
- func After(s string, substr string) string
- func AfterWord(s, substr string) string
- func Before(s string, substr string) string
- func Between(s, start, end string) string
- func BetweenIndex(s, start, end string) (int, int)
- func ContainsAny(s string, substr ...string) bool
- func EqualFoldAny(s string, substr ...string) bool
- func FirstLower(s string) string
- func FirstUpper(s string) string
- func HasPrefixes(s string, prefix ...string) bool
- func HasStrings(s string, substr ...string) bool
- func HasSuffixes(s string, suffix ...string) bool
- func SplitAfter(s, sep, substr string) string
- func SplitByIndex(s, sep string, index int) string
- func Title(s string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BetweenIndex ¶
BetweenIndex returns start and end indexes between two strings.
func ContainsAny ¶
ContainsAny returns true if the s contains any ony of the substr
func EqualFoldAny ¶
EqualFoldAny returns true if the s equal with case-insensitivity any one of the substr
func FirstLower ¶
func FirstUpper ¶
func HasPrefixes ¶
HasPrefixes returns string contains any one of the prefixes.
func HasStrings ¶
HasStrings returns true if the s equal any one of the substr
func HasSuffixes ¶
HasSuffixes returns string contains any one of the suffixes.
func SplitAfter ¶
SplitAfter returns a string after substr from the split string
func SplitByIndex ¶
SplitByIndex returns a string by index from the split string
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.